@@ -124,7 +124,9 @@ class _FieldDescriptor(object):
 
     def __get__(self, obj, objtype):
         if obj is None:
-            return self
+            # NOTE: return the *field* here rather than self;
+            # allows sphinx autodocumentation to inspect the type properly
+            return self.field
         return self.field.get_for_node(obj.node, obj.context)
 
     def __set__(self, obj, value):
@@ -440,6 +442,9 @@ class XmlObject(object):
         else:
             string_mode = False
 
+        # clean up unused namespace declarations before serializing
+        etree.cleanup_namespaces(node)
+
         # NOTE: etree c14n doesn't seem to like fedora info: URIs
         stream.write(etree.tostring(node, encoding='UTF-8', pretty_print=pretty,
                                     xml_declaration=xml_declaration))
